==> haskell-generics-sop-0.3.2.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-generics-sop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generics-sop
version: 0.3.2.0
id: generics-sop-0.3.2.0-DVZ1EAz7WZT3T0121HR4y2
key: generics-sop-0.3.2.0-DVZ1EAz7WZT3T0121HR4y2
license: BSD3
maintainer: andres@well-typed.com
synopsis: Generic Programming using True Sums of Products
description:
    A library to support the definition of generic functions.
    Datatypes are viewed in a uniform, structured way:
    the choice between constructors is represented using an n-ary
    sum, and the arguments of each constructor are represented using
    an n-ary product.
    .
    The module "Generics.SOP" is the main module of this library and contains
    more detailed documentation.
    .
    Examples of using this library are provided by the following
    packages:
    .
    * @<https://hackage.haskell.org/package/basic-sop basic-sop>@ basic examples,
    .
    * @<https://hackage.haskell.org/package/pretty-sop pretty-sop>@ generic pretty printing,
    .
    * @<https://hackage.haskell.org/package/lens-sop lens-sop>@ generically computed lenses,
    .
    * @<https://hackage.haskell.org/package/json-sop json-sop>@ generic JSON conversions.
    .
    A detailed description of the ideas behind this library is provided by
    the paper:
    .
    * Edsko de Vries and Andres Löh.
    <http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
    Workshop on Generic Programming (WGP) 2014.
    .
category: Generics
author: Edsko de Vries <edsko@well-typed.com>, Andres Löh <andres@well-typed.com>
exposed: True
indefinite: False
exposed-modules:
    Generics.SOP Generics.SOP.BasicFunctors Generics.SOP.Classes
    Generics.SOP.Constraint Generics.SOP.Dict Generics.SOP.GGP
    Generics.SOP.Instances Generics.SOP.Metadata Generics.SOP.NP
    Generics.SOP.NS Generics.SOP.Sing Generics.SOP.TH
    Generics.SOP.Type.Metadata Generics.SOP.Universe
abi: 86ec68c30c337bfc7bee44149d89cb9f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/generics-sop-0.3.2.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/generics-sop-0.3.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/generics-sop-0.3.2.0
hs-libraries: HSgenerics-sop-0.3.2.0-DVZ1EAz7WZT3T0121HR4y2
depends:
    base-4.10.1.0 template-haskell-2.12.0.0 ghc-prim-0.5.1.1
    deepseq-1.4.3.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
haddock-interfaces: /usr/share/doc/haskell-generics-sop/html/generics-sop.haddock
haddock-html: /usr/share/doc/haskell-generics-sop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generics-sop-0.3.2.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-generics-sop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generics-sop
version: 0.3.2.0
id: generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
key: generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
license: BSD-3-Clause
maintainer: andres@well-typed.com
author: Edsko de Vries <edsko@well-typed.com>, Andres Löh <andres@well-typed.com>
synopsis: Generic Programming using True Sums of Products
description:
    A library to support the definition of generic functions.
    Datatypes are viewed in a uniform, structured way:
    the choice between constructors is represented using an n-ary
    sum, and the arguments of each constructor are represented using
    an n-ary product.
    .
    The module "Generics.SOP" is the main module of this library and contains
    more detailed documentation.
    .
    Examples of using this library are provided by the following
    packages:
    .
    * @<https://hackage.haskell.org/package/basic-sop basic-sop>@ basic examples,
    .
    * @<https://hackage.haskell.org/package/pretty-sop pretty-sop>@ generic pretty printing,
    .
    * @<https://hackage.haskell.org/package/lens-sop lens-sop>@ generically computed lenses,
    .
    * @<https://hackage.haskell.org/package/json-sop json-sop>@ generic JSON conversions.
    .
    A detailed description of the ideas behind this library is provided by
    the paper:
    .
    * Edsko de Vries and Andres Löh.
    <http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
    Workshop on Generic Programming (WGP) 2014.
    .
category: Generics
abi: 4d4d502ecb3dc16eeeb1962a57e78b27
exposed: True
exposed-modules:
    Generics.SOP Generics.SOP.BasicFunctors Generics.SOP.Classes
    Generics.SOP.Constraint Generics.SOP.Dict Generics.SOP.GGP
    Generics.SOP.Instances Generics.SOP.Metadata Generics.SOP.NP
    Generics.SOP.NS Generics.SOP.Sing Generics.SOP.TH
    Generics.SOP.Type.Metadata Generics.SOP.Universe
import-dirs: /usr/lib/ghc-8.4.2/site-local/generics-sop-0.3.2.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/generics-sop-0.3.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/generics-sop-0.3.2.0
hs-libraries: HSgenerics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
depends:
    base-4.11.1.0 template-haskell-2.13.0.0 ghc-prim-0.5.2.0
    deepseq-1.4.3.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             template-haskell-2.13.0.0=b25d144eee230069f091d0d8982b331b
             ghc-prim-0.5.2.0=a22477c99003a90dd639dbfd07997615
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
haddock-interfaces: /usr/share/doc/haskell-generics-sop/html/generics-sop.haddock
haddock-html: /usr/share/doc/haskell-generics-sop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
